@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,9 +23,8 @@
 
 G_BEGIN_DECLS
 
-GList * g_document_portal_add_documents (GList       *uris,
-                                         const char  *app_id,
-                                         GError     **error);
+char * g_document_portal_add_document (GFile   *file,
+                                       GError **error);
 
 G_END_DECLS
 
