@@ -1,12 +1,10 @@
 /*
  * Copyright 2015 Red Hat, Inc.
  *
- * SPDX-License-Identifier: LGPL-2.1-or-later
- *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * version 2 of the licence, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,22 +28,20 @@
 
 static char *attr_type = "string";
 static gboolean nofollow_symlinks = FALSE;
-static gboolean delete = FALSE;
 
 static const GOptionEntry entries[] = {
   { "type", 't', 0, G_OPTION_ARG_STRING, &attr_type, N_("Type of the attribute"), N_("TYPE") },
   { "nofollow-symlinks", 'n', 0, G_OPTION_ARG_NONE, &nofollow_symlinks, N_("Don’t follow symbolic links"), NULL },
-  { "delete", 'd', 0, G_OPTION_ARG_NONE, &delete, N_("Unset given attribute"), NULL },
-  G_OPTION_ENTRY_NULL
+  { NULL }
 };
 
 static char *
 hex_unescape (const char *str)
 {
-  size_t i;
+  int i;
   char *unescaped_str, *p;
   unsigned char c;
-  size_t len;
+  int len;
 
   len = strlen (str);
   unescaped_str = g_malloc (len + 1);
@@ -80,19 +76,17 @@ handle_set (int argc, char *argv[], gboolean do_help)
   const char *attribute;
   GFileAttributeType type;
   gpointer value;
-  gpointer value_allocated = NULL;
   gboolean b;
   guint32 uint32;
   gint32 int32;
   guint64 uint64;
   gint64 int64;
   gchar *param;
-  int retval = 0;
 
   g_set_prgname ("gio set");
 
   /* Translators: commandline placeholder */
-  param = g_strdup_printf ("%s %s %s…", _("LOCATION"), _("ATTRIBUTE"), _("VALUE"));
+  param = g_strdup_printf ("%s %s %s...", _("LOCATION"), _("ATTRIBUTE"), _("VALUE"));
   context = g_option_context_new (param);
   g_free (param);
   g_option_context_set_help_enabled (context, FALSE);
@@ -102,7 +96,6 @@ handle_set (int argc, char *argv[], gboolean do_help)
   if (do_help)
     {
       show_help (context, NULL);
-      g_option_context_free (context);
       return 0;
     }
 
@@ -110,45 +103,35 @@ handle_set (int argc, char *argv[], gboolean do_help)
     {
       show_help (context, error->message);
       g_error_free (error);
-      g_option_context_free (context);
       return 1;
     }
 
   if (argc < 2)
     {
       show_help (context, _("Location not specified"));
-      g_option_context_free (context);
       return 1;
     }
 
+  file = g_file_new_for_commandline_arg (argv[1]);
+
   if (argc < 3)
     {
       show_help (context, _("Attribute not specified"));
-      g_option_context_free (context);
       return 1;
     }
 
   attribute = argv[2];
-  if (delete)
-    {
-      type = G_FILE_ATTRIBUTE_TYPE_INVALID;
-    }
-  else
-    {
-      type = attribute_type_from_string (attr_type);
-    }
 
+  type = attribute_type_from_string (attr_type);
   if ((argc < 4) && (type != G_FILE_ATTRIBUTE_TYPE_INVALID))
     {
       show_help (context, _("Value not specified"));
-      g_option_context_free (context);
       return 1;
     }
 
   if ((argc > 4) && (type != G_FILE_ATTRIBUTE_TYPE_STRINGV))
     {
       show_help (context, _("Too many arguments"));
-      g_option_context_free (context);
       return 1;
     }
 
@@ -160,7 +143,7 @@ handle_set (int argc, char *argv[], gboolean do_help)
       value = argv[3];
       break;
     case G_FILE_ATTRIBUTE_TYPE_BYTE_STRING:
-      value = value_allocated = hex_unescape (argv[3]);
+      value = hex_unescape (argv[3]);
       break;
     case G_FILE_ATTRIBUTE_TYPE_BOOLEAN:
       b = g_ascii_strcasecmp (argv[3], "true") == 0;
@@ -190,12 +173,10 @@ handle_set (int argc, char *argv[], gboolean do_help)
       break;
     case G_FILE_ATTRIBUTE_TYPE_OBJECT:
     default:
-      print_error (_("Invalid attribute type “%s”"), attr_type);
+      g_printerr (_("Invalid attribute type %s\n"), attr_type);
       return 1;
     }
 
-  file = g_file_new_for_commandline_arg (argv[1]);
-
   if (!g_file_set_attribute (file,
 			     attribute,
 			     type,
@@ -205,13 +186,10 @@ handle_set (int argc, char *argv[], gboolean do_help)
                                G_FILE_QUERY_INFO_NONE,
                              NULL, &error))
     {
-      print_error ("%s", error->message);
+      g_printerr (_("Error setting attribute: %s\n"), error->message);
       g_error_free (error);
-      retval = 1;
+      return 1;
     }
 
-  g_clear_pointer (&value_allocated, g_free);
-  g_object_unref (file);
-
-  return retval;
+  return 0;
 }
