@@ -349,7 +349,7 @@ _g_local_file_output_stream_really_close (GLocalFileOutputStream *file,
 
 #ifndef G_OS_WIN32
   /* A simple try to close the fd in case we fail before the actual close */
-  (void) g_close (file->priv->fd, NULL);
+  g_close (file->priv->fd, NULL);
 #endif
   if (file->priv->tmp_filename)
     g_unlink (file->priv->tmp_filename);
@@ -552,7 +552,7 @@ set_error_from_open_errno (const char *filename,
       char *display_name = g_filename_display_name (filename);
       g_set_error (error, G_IO_ERROR,
                    g_io_error_from_errno (errsv),
-                   _("Error opening file '%s': %s"),
+                   _("Error opening file “%s”: %s"),
 		       display_name, g_strerror (errsv));
       g_free (display_name);
     }
@@ -782,7 +782,7 @@ handle_overwrite_open (const char    *filename,
       char *display_name = g_filename_display_name (filename);
       g_set_error (error, G_IO_ERROR,
 		   g_io_error_from_errno (errsv),
-		   _("Error opening file '%s': %s"),
+		   _("Error opening file “%s”: %s"),
 		   display_name, g_strerror (errsv));
       g_free (display_name);
       return -1;
@@ -800,7 +800,7 @@ handle_overwrite_open (const char    *filename,
       char *display_name = g_filename_display_name (filename);
       g_set_error (error, G_IO_ERROR,
 		   g_io_error_from_errno (errsv),
-		   _("Error when getting information for file '%s': %s"),
+		   _("Error when getting information for file “%s”: %s"),
 		   display_name, g_strerror (errsv));
       g_free (display_name);
       goto err_out;
@@ -893,14 +893,14 @@ handle_overwrite_open (const char    *filename,
 	      original_stat.st_gid != tmp_statbuf.st_gid ||
 	      original_stat.st_mode != tmp_statbuf.st_mode)
 	    {
-	      (void) g_close (tmpfd, NULL);
+	      g_close (tmpfd, NULL);
 	      g_unlink (tmp_filename);
 	      g_free (tmp_filename);
 	      goto fallback_strategy;
 	    }
 	}
 
-      (void) g_close (fd, NULL);
+      g_close (fd, NULL);
       *temp_filename = tmp_filename;
       return tmpfd;
     }
@@ -953,6 +953,7 @@ handle_overwrite_open (const char    *filename,
                                G_IO_ERROR_CANT_CREATE_BACKUP,
                                _("Backup file creation failed"));
 	  g_unlink (backup_filename);
+	  g_close (bfd, NULL);
 	  g_free (backup_filename);
 	  goto err_out;
 	}
@@ -969,7 +970,7 @@ handle_overwrite_open (const char    *filename,
                                    G_IO_ERROR_CANT_CREATE_BACKUP,
                                    _("Backup file creation failed"));
 	      g_unlink (backup_filename);
-	      (void) g_close (bfd, NULL);
+	      g_close (bfd, NULL);
 	      g_free (backup_filename);
 	      goto err_out;
 	    }
@@ -983,13 +984,13 @@ handle_overwrite_open (const char    *filename,
                                G_IO_ERROR_CANT_CREATE_BACKUP,
                                _("Backup file creation failed"));
 	  g_unlink (backup_filename);
-          (void) g_close (bfd, NULL);
+          g_close (bfd, NULL);
 	  g_free (backup_filename);
 	  
 	  goto err_out;
 	}
       
-      (void) g_close (bfd, NULL);
+      g_close (bfd, NULL);
       g_free (backup_filename);
 
       /* Seek back to the start of the file after the backup copy */
@@ -1007,7 +1008,7 @@ handle_overwrite_open (const char    *filename,
 
   if (flags & G_FILE_CREATE_REPLACE_DESTINATION)
     {
-      (void) g_close (fd, NULL);
+      g_close (fd, NULL);
       
       if (g_unlink (filename) != 0)
 	{
@@ -1031,7 +1032,7 @@ handle_overwrite_open (const char    *filename,
 	  char *display_name = g_filename_display_name (filename);
 	  g_set_error (error, G_IO_ERROR,
 		       g_io_error_from_errno (errsv),
-		       _("Error opening file '%s': %s"),
+		       _("Error opening file “%s”: %s"),
 		       display_name, g_strerror (errsv));
 	  g_free (display_name);
 	  goto err_out2;
@@ -1059,7 +1060,7 @@ handle_overwrite_open (const char    *filename,
   return fd;
 
  err_out:
-  (void) g_close (fd, NULL);
+  g_close (fd, NULL);
  err_out2:
   return -1;
 }
